%global commit f849f6d9bd21efe802fa456184b1c3173e74a050
%global shortcommit %(c=%{commit}; echo ${c:0:7})

Name:           assimp
Version:        3.0.1270
Release:        11%{?dist}
Summary:        Library to import various 3D model formats into applications

Group:          Development/Libraries
License:        BSD
URL:            http://assimp.sourceforge.net
# This is the source location, but use assimp_generate_tarball to remove the non-free
# model files from the source distribution.
#Source0:        https://github.com/%{name}/%{name}/archive/%{commit}/%{name}-%{version}-%{shortcommit}.tar.gz
Source0:	%{name}-%{commit}-free.tar.bz2
# Assimp tarball comes with non-free models which must be removed from the source distribution
Source1:        assimp_generate_tarball.sh

# Strips bundled irrXML out of build files, and allows project to build
# against system versions of the libraries (not yet submitted upstream) 
Patch0:         %{name}-3.0.1270-unbundle.patch
# Change a doxygen setting so CHM help isn't generated
Patch1:         %{name}-1.1.700.docfix.patch
Patch2:         %{name}-2.0.863.pkgconfig.patch
Patch3:         %{name}-1071-gcc47.patch
Patch4:         %{name}-pythonpath.patch
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  irrlicht-devel
BuildRequires:  irrXML-devel
BuildRequires:  zlib-devel
BuildRequires:  doxygen
BuildRequires:  minizip-devel
BuildRequires:  poly2tri-devel
BuildRequires:  polyclipping-devel
BuildRequires:  python-devel
BuildRequires:  python3-devel

%description
Assimp, the Open Asset Import Library, is a free library to import 
various well-known 3D model formats into applications.  Assimp aims 
to provide a full asset conversion pipeline for use in game 
engines and real-time rendering systems, but is not limited 
to these applications.

%package devel
Summary: Header files and libraries for assimp
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
This package contains the header files and libraries
for assimp. If you would like to develop programs using assimp,
you will need to install assimp-devel.

%package python
Summary: Python bindings for assimp
Group: Development/Libraries
BuildArch: noarch
Requires: %{name} = %{version}-%{release}
Requires: python

%description python
This package contains the PyAssimp python bindings

%package python3
Summary: Python 3 bindings for assimp
Group: Development/Libraries
BuildArch: noarch
Requires: %{name} = %{version}-%{release}
Requires: python3

%description python3
This package contains the PyAssimp3 python bindings

%prep
%setup -q -n %{name}-%{commit}
# Get rid of bundled libs so we can't accidently build against them
rm -rf contrib/cppunit-1.12.1
rm -rf contrib/irrXML
rm -rf contrib/zlib
rm -rf contrib/unzip
rm -rf contrib/poly2tri
%patch0 -p1 -b .unbundle
%patch1 -p1
%patch2 -p1
#%patch3 -p0
%patch4 -p0

%build
mkdir build
pushd build
%cmake  -DLIB_INSTALL_DIR=%{_libdir} -DINCLUDE_INSTALL_DIR=%{_includedir} -DBIN_INSTALL_DIR=%{_bindir} -DIRRXML_LIB_PATH=%{_libdir} -DIRRXML_INCLUDE_PATH=%{_includedir}/irrlicht/ -DPOLY2TRI_INCLUDE_PATH=%{_includedir}/poly2tri -DUSE_EXTERNAL_LIBS=ON ..
popd
make %{?_smp_mflags} -C build

# Generate docs, copy assimp logo image and stylesheet into generated docs
pushd doc
doxygen Doxyfile
cp AssimpDoc_Html/dragonsplash.png html/dragonsplash.png
popd

# Fix file encoding
dos2unix README LICENSE CREDITS port/PyAssimp/README port/PyAssimp3/README
iconv -f iso8859-1 -t utf-8 CREDITS > CREDITS.conv && mv -f CREDITS.conv CREDITS

%install
rm -rf %{buildroot}
make -C build install DESTDIR=%{buildroot}
mkdir -p %{buildroot}%{python2_sitelib}/pyassimp/
install -m0644 port/PyAssimp/pyassimp/*.py %{buildroot}%{python2_sitelib}/pyassimp/
mkdir -p %{buildroot}%{python3_sitelib}/pyassimp/
install -m0644 port/PyAssimp3/pyassimp/*.py %{buildroot}%{python3_sitelib}/pyassimp/

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%doc README LICENSE CREDITS
%{_bindir}/assimp
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%doc doc/html
%{_includedir}/assimp
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/%{name}-3.0

%files python
%doc port/PyAssimp/README
%{python_sitelib}/pyassimp

%files python3
%doc port/PyAssimp3/README
%{python3_sitelib}/pyassimp

%changelog
* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.1270-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 3.0.1270-10
- Rebuilt for GCC 5 C++11 ABI change

* Mon Jan 26 2015 Petr Machata <pmachata@redhat.com> - 3.0.1270-9
- Rebuild for boost 1.57.0

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.1270-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.1270-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 28 2014 Kalev Lember <kalevlember@gmail.com> - 3.0.1270-6
- Rebuilt for https://fedoraproject.org/wiki/Changes/Python_3.4

* Thu May 22 2014 Petr Machata <pmachata@redhat.com> - 3.0.1270-5
- Rebuild for boost 1.55.0

* Sun Mar 02 2014 Scott K Logan <logans@cottsay.net> - 3.0.1270-4
- Changed upstream source to Github
- Un-commented assimp-python, added python-devel to build deps
- Added assimp-python3 subpackage

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.1270-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 30 2013 Petr Machata <pmachata@redhat.com> - 3.0.1270-2
- Rebuild for boost 1.54.0

* Wed May 01 2013 Rich Mattes <richmattes@gmail.com> 3.0.1270-1
- Update to release 3.0.1270

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.863-9.20110824svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Oct 25 2012 Rich Mattes <richmattes@gmail.com> - 2.0.863-8.20110824svn
- Install python bindings

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.863-7.20110824svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jul  3 2012 Tom Callaway <spot@fedoraproject.org> - 2.0.863-6.20110824svn
- rebuild against new irrlicht/irrxml

* Wed Apr 11 2012 Rich Mattes <richmattes@gmail.com> - 2.0.863-5.20110824svn
- Changed spec to use buildroot macro

* Sat Dec 17 2011 Rich Mattes <richmattes@gmail.com> - 2.0.863-4.20110824svn
- Fixed pkgconfig paths

* Wed Aug 24 2011 Rich Mattes <richmattes@gmail.com> - 2.0.863-3.20110824svn
- Upgrade to latest svn snapshot
- Port changes to link against system irrXML
- Removed upstreamed zlib/unzip unbundling patches

* Thu Mar 24 2011 Rich Mattes <richmattes@gmail.com> - 2.0.863-2.20110324svn
- Upgrade to latest svn snapshot
- Port changes to link against libIrrXML

* Sat Dec 18 2010 Rich Mattes <richmattes@gmail.com> - 2.0.863-1
- Upgrade to release 2.0

* Mon Sep 20 2010 Rich Mattes <richmattes@gmail.com> - 1.1.700-3
- Remove extra buildrequires
- Generate doxygen docs manually

* Mon Sep 20 2010 Rich Mattes <richmattes@gmail.com> - 1.1.700-2
- Included doxygen-generated docs
- Using original .zip file from project download page

* Sun Sep 19 2010 Rich Mattes <richmattes@gmail.com> - 1.1.700-1
- First build
